@@ -13,7 +13,7 @@
 #' }
 #' @export
 
-packageVersionPercent <- function(lst, yr.mo = "2020-07", multi.core = TRUE) {
+packageVersionPercent <- function(lst, yr.mo = "2020-07", multi.core = FALSE) {
   cores <- multiCore(multi.core)
 
   if (is.null(lst)) {
@@ -30,10 +30,16 @@ packageVersionPercent <- function(lst, yr.mo = "2020-07", multi.core = TRUE) {
       arch.pkgs <- packageRank::blog.data$arch.pkgs.jul
     }
   }
-
+  
   pkgs <- c(cran.pkgs, arch.pkgs)
-  pkg.data <- lapply(pkgs, function(x) computeVersionPercents(lst, x, cores))
+  histories <- lapply(pkgs, packageHistory)
+  names(histories) <- pkgs
+  
+  pkg.data <- lapply(pkgs, function(x) {
+    computeVersionPercents(lst, x, histories)
+  })
   names(pkg.data) <- pkgs
+  
   out <- list(cran.pkgs = cran.pkgs, arch.pkgs = arch.pkgs, pkg.data = pkg.data)
   class(out) <- "packageVersionPercent"
   out
@@ -52,39 +58,36 @@ monthlyLog <- function(yr.mo = "2020-07") {
   start.date <- fixDate_2012(start.date)
   end.date <- fixDate_2012(end.date)
   days <- seq(start.date, end.date, by = "day")
-  lapply(days, fetchCranLog)
+  out <- lapply(days, fetchCranLog)
+  names(out) <- days
+  out
 }
 
-computeVersionPercents <- function(lst, pkgs, cores) {
+computeVersionPercents <- function(lst, pkg, histories) {
   dates <- as.Date(names(lst))
   end.date <- dates[length(dates)]
-  obs.ver.ct <- observedVersionCount(lst, pkgs, cores)
-  exp.ver.ct <- expectedVersionCount(pkgs, end.date + 1)
-  out <- lapply(seq_along(obs.ver.ct), function(i) {
-    data.frame(date = dates[i], package = names(obs.ver.ct[[i]]),
-               obs = obs.ver.ct[[i]], row.names = NULL)
-  })
-  out <- do.call(rbind, out)
-  out$exp <- exp.ver.ct
+  obs.ver.ct <- observedVersionCount(lst, pkg)
+  exp.ver.ct <- expectedVersionCount(histories, pkg, dates)
+  out <- data.frame(date = dates, package = pkg, obs = obs.ver.ct, 
+    exp = exp.ver.ct, row.names = NULL)
   out$pct.of.versions <- 100 * out$obs / out$exp
   out
 }
 
-observedVersionCount <- function(lst, pkgs, cores) {
-  parallel::mclapply(lst, function(x) {
-    vapply(pkgs, function(p) {
-      length(unique(x[!is.na(x$package) & x$package == p, "version"]))
-    }, integer(1L))
-  }, mc.cores = cores)
+observedVersionCount <- function(lst, pkg) {
+  vapply(lst, function(x) {
+      length(unique(x[!is.na(x$package) & x$package == pkg, "version"]))
+  }, integer(1L))
 }
 
-expectedVersionCount <- function(pkgs, end.date) {
-  h <- lapply(pkgs, packageHistory0)
-  vapply(h, function(x) sum(x$date < end.date), integer(1L))
+expectedVersionCount <- function(histories, pkg, dates) {
+  vapply(seq_along(dates), function(i) {
+    sum(histories[[paste(pkg)]]$Date <= dates[i])
+  }, integer(1L))
 }
 
 #' Plot method for packageVersionPercent().
-#' @param x An object of class "packageVersions" created by \code{packageVersions()}.
+#' @param x An object of class "packageVersionPercent".
 #' @param ... Additional plotting parameters.
 #' @export
 
@@ -96,24 +99,26 @@ plot.packageVersionPercent <- function(x, ...) {
   titleB <- 'CRAN (1-100) & Archive (101-200)'
   # titleC <- paste0(':', month(pkg.data[1, "date"]), year(pkg.data[1, "date"]))
 
-  ggplot(data = pkg.data, aes_string(x = "id", y = "pct.of.versions")) +
-    geom_point(color = "gray") +
-    geom_smooth(method = "loess", formula = "y ~ x", se = FALSE,
-      color = "red", size = 1.5) +
+  ggplot2::ggplot(data = pkg.data, 
+                  ggplot2::aes(x = .data$id, y = .data$pct.of.versions)) +
+    ggplot2::geom_point(color = "gray") +
+    ggplot2::geom_smooth(method = "loess", formula = "y ~ x", se = FALSE,
+      color = "red", linewidth = 1.5) +
 
     # https://github.com/tidyverse/ggplot2/issues/2963
     # geom_vline(xintercept) --> geom_vline(aes(xintercept))
-    geom_vline(aes(xintercept = 99.5), col = "black", linetype = "dashed") +
+    ggplot2::geom_vline(aes(xintercept = 99.5), col = "black", 
+      linetype = "dashed") +
 
-    xlab("Package ID") +
-    ylab("Percent") +
+    ggplot2::xlab("Package ID") +
+    ggplot2::ylab("Percent") +
     sugrrants::facet_calendar(~ as.Date(date), week_start = 7) +
-    theme_bw() +
-    theme(panel.grid.minor = element_blank(),
-          panel.grid.major = element_blank(),
-          plot.title = element_text(hjust = 0.5)) +
-    scale_y_continuous(breaks = c(0, 50, 100), limits = c(-10, 110)) +
-    scale_x_continuous(breaks = 100) +
+    ggplot2::theme_bw() +
+    ggplot2::theme(panel.grid.minor = ggplot2::element_blank(),
+                   panel.grid.major = ggplot2::element_blank(),
+                   plot.title = ggplot2::element_text(hjust = 0.5)) +
+    ggplot2::scale_y_continuous(breaks = c(0, 50, 100), limits = c(-10, 110)) +
+    ggplot2::scale_x_continuous(breaks = 100) +
     # ggtitle(paste(titleA, titleB, titleC))
-    ggtitle(paste(titleB))
+    ggplot2::ggtitle(paste(titleB))
 }
