@@ -2,9 +2,7 @@
 #'
 #' @export
 
-utc <- function() {
-  as.POSIXlt(as.numeric(Sys.time()), origin = "1970-01-01", tz = "GMT")
-}
+utc <- function() as.POSIXct(Sys.time(), tz = "UTC")
 
 #' Compute Coordinated Universal Time (UTC/GMT) for Specified Local Time.
 #'
@@ -17,9 +15,7 @@ utc0 <- function(date = "2020-01-01", time = "12:00:00", tz = "Europe/Vienna") {
   local.date <- as.Date(date, optional = TRUE)
   if (is.na(local.date)) {
     stop('Invalid date or format "yyyy-mm-dd".', call. = FALSE)
-  }
-  x <- dateTime(date = local.date, time = time, tz = tz)
-  as.POSIXlt(as.numeric(x), origin = "1970-01-01", tz = "GMT")
+  } else as.POSIXct(paste(local.date, time), tz = tz)
 }
 
 #' Compute Current Time in Selected Time Zone.
@@ -27,9 +23,7 @@ utc0 <- function(date = "2020-01-01", time = "12:00:00", tz = "Europe/Vienna") {
 #' @param tz Character. Local time zone. See OlsonNames() or use Sys.timezone().
 #' @export
 
-currentTime <- function(tz = "Australia/Sydney") {
-  as.POSIXct(as.numeric(Sys.time()), origin = "1970-01-01", tz = tz)
-}
+currentTime <- function(tz = "Australia/Sydney") as.POSIXct(Sys.time(), tz = tz)
 
 #' Compute Local Time from Coordinated Universal Time (UTC/GMT).
 #'
@@ -42,7 +36,5 @@ localTime <- function(date = "2021-1-1", time = "12:00", tz = Sys.timezone()) {
   local.date <- as.Date(date, optional = TRUE)
   if (is.na(local.date)) {
     stop('Invalid date or format "yyyy-mm-dd".', call. = FALSE)
-  }
-  x <- dateTime(local.date, time)
-  as.POSIXlt(as.numeric(x), origin = "1970-01-01", tz = tz)
+  } else dateTime(local.date, time, tz = tz)
 }
